<?php

namespace Drupal\imago\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configuration form for the Article candidate module.
 */
class ImagoSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['imago.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'imago_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('imago.settings');

    $form = [
      '#type' => 'details',
      '#title' => t('Imago API settings.', [], ['context' => 'imago']),
      '#open' => TRUE,
      '#tree' => TRUE,
    ];
    $form['api'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('API settings'),
    ];
    $form['api']['base_url'] = [
      '#title' => $this->t('Base API URL.', [], ['context' => 'imago']),
      '#type' => 'textfield',
      '#size' => 60,
      '#default_value' => ($config->get('api')['base_url']) ?? NULL,
    ];
    $form['api']['query'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Search'),
    ];
    $form['api']['query']['api_url'] = [
      '#title' => $this->t('Search API URL.', [], ['context' => 'imago']),
      '#type' => 'textfield',
      '#size' => 60,
      '#default_value' => ($config->get('api')['query']['api_url']) ?? NULL,
    ];
    $form['api']['download'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Download'),
    ];
    $form['api']['download']['api_url'] = [
      '#title' => $this->t('Download API URL.', [], ['context' => 'imago']),
      '#type' => 'textfield',
      '#size' => 60,
      '#default_value' => ($config->get('api')['download']['api_url']) ?? NULL,
    ];
    $form['api']['api_user'] = [
      '#title' => $this->t('API user.', [], ['context' => 'imago']),
      '#type' => 'textfield',
      '#size' => 60,
      '#default_value' => ($config->get('api')['api_user']) ?? NULL,
    ];
    $form['api']['api_key'] = [
      '#title' => $this->t('API key', [], ['context' => 'imago']),
      '#type' => 'password',
      '#size' => 60,
      '#default_value' => ($config->get('api')['api_key']) ?? NULL,
    ];
    $media_types = $types = \Drupal::entityTypeManager()->getStorage('media_type')->loadMultiple();
    $options = [];
    foreach ($media_types as $media_type) {
      $options[$media_type->id()] = $media_type->label();
    }
    $form['media'] = [
      '#type' => 'select',
      '#title' => $this->t('Allowed media'),
      '#options' => $options,
      '#default_value' => ($config->get('media')) ?? NULL,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('imago.settings');
    $api = $form_state->getValue('api');
    $media = $form_state->getValue('media');
    if (empty($api['api-key'])) {
      $api['api-key'] = $config->get('api')['api-key'];
    }

    $this->config('imago.settings')
      ->set('api', $api)
      ->set('media', $media)
      ->save();
    parent::submitForm($form, $form_state);
  }

}
